import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def armature_apply(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    selected: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Apply the current pose as the new rest pose

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param selected: Selected Only, Only apply the selected bones (with propagation to children)
    :type selected: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def autoside_names(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    axis: typing.Optional[typing.Any] = "XAXIS",
):
    """Automatically renames the selected bones according to which side of the target axis they fall on

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param axis: Axis, Axis to tag names with

    XAXIS
    X-Axis -- Left/Right.

    YAXIS
    Y-Axis -- Front/Back.

    ZAXIS
    Z-Axis -- Top/Bottom.
        :type axis: typing.Optional[typing.Any]
    """

    ...

def blend_to_neighbor(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    factor: typing.Optional[typing.Any] = 0.5,
    prev_frame: typing.Optional[typing.Any] = 0,
    next_frame: typing.Optional[typing.Any] = 0,
    channels: typing.Optional[typing.Any] = "ALL",
    axis_lock: typing.Optional[typing.Any] = "FREE",
):
    """Blend from current position to previous or next keyframe

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param factor: Factor, Weighting factor for which keyframe is favored more
        :type factor: typing.Optional[typing.Any]
        :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame
        :type prev_frame: typing.Optional[typing.Any]
        :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame
        :type next_frame: typing.Optional[typing.Any]
        :param channels: Channels, Set of properties that are affected

    ALL
    All Properties -- All properties, including transforms, bendy bone shape, and custom properties.

    LOC
    Location -- Location only.

    ROT
    Rotation -- Rotation only.

    SIZE
    Scale -- Scale only.

    BBONE
    Bendy Bone -- Bendy Bone shape properties.

    CUSTOM
    Custom Properties -- Custom properties.
        :type channels: typing.Optional[typing.Any]
        :param axis_lock: Axis Lock, Transform axis to restrict effects to

    FREE
    Free -- All axes are affected.

    X
    X -- Only X-axis transforms are affected.

    Y
    Y -- Only Y-axis transforms are affected.

    Z
    Z -- Only Z-axis transforms are affected.
        :type axis_lock: typing.Optional[typing.Any]
    """

    ...

def blend_with_rest(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    factor: typing.Optional[typing.Any] = 0.5,
    prev_frame: typing.Optional[typing.Any] = 0,
    next_frame: typing.Optional[typing.Any] = 0,
    channels: typing.Optional[typing.Any] = "ALL",
    axis_lock: typing.Optional[typing.Any] = "FREE",
):
    """Make the current pose more similar to, or further away from, the rest pose

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param factor: Factor, Weighting factor for which keyframe is favored more
        :type factor: typing.Optional[typing.Any]
        :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame
        :type prev_frame: typing.Optional[typing.Any]
        :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame
        :type next_frame: typing.Optional[typing.Any]
        :param channels: Channels, Set of properties that are affected

    ALL
    All Properties -- All properties, including transforms, bendy bone shape, and custom properties.

    LOC
    Location -- Location only.

    ROT
    Rotation -- Rotation only.

    SIZE
    Scale -- Scale only.

    BBONE
    Bendy Bone -- Bendy Bone shape properties.

    CUSTOM
    Custom Properties -- Custom properties.
        :type channels: typing.Optional[typing.Any]
        :param axis_lock: Axis Lock, Transform axis to restrict effects to

    FREE
    Free -- All axes are affected.

    X
    X -- Only X-axis transforms are affected.

    Y
    Y -- Only Y-axis transforms are affected.

    Z
    Z -- Only Z-axis transforms are affected.
        :type axis_lock: typing.Optional[typing.Any]
    """

    ...

def breakdown(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    factor: typing.Optional[typing.Any] = 0.5,
    prev_frame: typing.Optional[typing.Any] = 0,
    next_frame: typing.Optional[typing.Any] = 0,
    channels: typing.Optional[typing.Any] = "ALL",
    axis_lock: typing.Optional[typing.Any] = "FREE",
):
    """Create a suitable breakdown pose on the current frame

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param factor: Factor, Weighting factor for which keyframe is favored more
        :type factor: typing.Optional[typing.Any]
        :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame
        :type prev_frame: typing.Optional[typing.Any]
        :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame
        :type next_frame: typing.Optional[typing.Any]
        :param channels: Channels, Set of properties that are affected

    ALL
    All Properties -- All properties, including transforms, bendy bone shape, and custom properties.

    LOC
    Location -- Location only.

    ROT
    Rotation -- Rotation only.

    SIZE
    Scale -- Scale only.

    BBONE
    Bendy Bone -- Bendy Bone shape properties.

    CUSTOM
    Custom Properties -- Custom properties.
        :type channels: typing.Optional[typing.Any]
        :param axis_lock: Axis Lock, Transform axis to restrict effects to

    FREE
    Free -- All axes are affected.

    X
    X -- Only X-axis transforms are affected.

    Y
    Y -- Only Y-axis transforms are affected.

    Z
    Z -- Only Z-axis transforms are affected.
        :type axis_lock: typing.Optional[typing.Any]
    """

    ...

def constraint_add(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    type: typing.Optional[typing.Union[str, int]] = "",
):
    """Add a constraint to the active bone

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Optional[typing.Union[str, int]]
    """

    ...

def constraint_add_with_targets(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    type: typing.Optional[typing.Union[str, int]] = "",
):
    """Add a constraint to the active bone, with target (where applicable) set to the selected Objects/Bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Type
    :type type: typing.Optional[typing.Union[str, int]]
    """

    ...

def constraints_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Clear all constraints from the selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def constraints_copy(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Copy constraints to other selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def copy(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Copy the current pose of the selected bones to the internal clipboard

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def flip_names(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    do_strip_numbers: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Flips (and corrects) the axis suffixes of the names of selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param do_strip_numbers: Strip Numbers, Try to remove right-most dot-number from flipped names.Warning: May result in incoherent naming in some cases
    :type do_strip_numbers: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def hide(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    unselected: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Tag selected bones to not be visible in Pose Mode

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param unselected: Unselected
    :type unselected: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def ik_add(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    with_targets: typing.Optional[typing.Union[bool, typing.Any]] = True,
):
    """Add IK Constraint to the active Bone

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param with_targets: With Targets, Assign IK Constraint with targets derived from the select bones/objects
    :type with_targets: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def ik_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Remove all IK Constraints from selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def loc_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Reset locations of selected bones to their default values

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def paste(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
    selected_mask: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Paste the stored pose on to the current pose

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param flipped: Flipped on X-Axis, Paste the stored pose flipped on to current pose
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    :param selected_mask: On Selected Only, Only paste the stored pose on to selected bones in the current pose
    :type selected_mask: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def paths_calculate(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    display_type: typing.Optional[typing.Union[str, int]] = "RANGE",
    range: typing.Optional[typing.Union[str, int]] = "SCENE",
    bake_location: typing.Optional[typing.Union[str, int]] = "HEADS",
):
    """Calculate paths for the selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param display_type: Display type
    :type display_type: typing.Optional[typing.Union[str, int]]
    :param range: Computation Range
    :type range: typing.Optional[typing.Union[str, int]]
    :param bake_location: Bake Location, Which point on the bones is used when calculating paths
    :type bake_location: typing.Optional[typing.Union[str, int]]
    """

    ...

def paths_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    only_selected: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Undocumented, consider contributing.

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param only_selected: Only Selected, Only clear motion paths of selected bones
    :type only_selected: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def paths_range_update(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Update frame range for motion paths from the Scene's current frame range

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def paths_update(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Recalculate paths for bones that already have them

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def propagate(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    mode: typing.Optional[typing.Any] = "NEXT_KEY",
    end_frame: typing.Optional[typing.Any] = 250.0,
):
    """Copy selected aspects of the current pose to subsequent poses already keyframed

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param mode: Terminate Mode, Method used to determine when to stop propagating pose to keyframes

    NEXT_KEY
    To Next Keyframe -- Propagate pose to first keyframe following the current frame only.

    LAST_KEY
    To Last Keyframe -- Propagate pose to the last keyframe only (i.e. making action cyclic).

    BEFORE_FRAME
    Before Frame -- Propagate pose to all keyframes between current frame and 'Frame' property.

    BEFORE_END
    Before Last Keyframe -- Propagate pose to all keyframes from current frame until no more are found.

    SELECTED_KEYS
    On Selected Keyframes -- Propagate pose to all selected keyframes.

    SELECTED_MARKERS
    On Selected Markers -- Propagate pose to all keyframes occurring on frames with Scene Markers after the current frame.
        :type mode: typing.Optional[typing.Any]
        :param end_frame: End Frame, Frame to stop propagating frames to (for 'Before Frame' mode)
        :type end_frame: typing.Optional[typing.Any]
    """

    ...

def push(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    factor: typing.Optional[typing.Any] = 0.5,
    prev_frame: typing.Optional[typing.Any] = 0,
    next_frame: typing.Optional[typing.Any] = 0,
    channels: typing.Optional[typing.Any] = "ALL",
    axis_lock: typing.Optional[typing.Any] = "FREE",
):
    """Exaggerate the current pose in regards to the breakdown pose

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param factor: Factor, Weighting factor for which keyframe is favored more
        :type factor: typing.Optional[typing.Any]
        :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame
        :type prev_frame: typing.Optional[typing.Any]
        :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame
        :type next_frame: typing.Optional[typing.Any]
        :param channels: Channels, Set of properties that are affected

    ALL
    All Properties -- All properties, including transforms, bendy bone shape, and custom properties.

    LOC
    Location -- Location only.

    ROT
    Rotation -- Rotation only.

    SIZE
    Scale -- Scale only.

    BBONE
    Bendy Bone -- Bendy Bone shape properties.

    CUSTOM
    Custom Properties -- Custom properties.
        :type channels: typing.Optional[typing.Any]
        :param axis_lock: Axis Lock, Transform axis to restrict effects to

    FREE
    Free -- All axes are affected.

    X
    X -- Only X-axis transforms are affected.

    Y
    Y -- Only Y-axis transforms are affected.

    Z
    Z -- Only Z-axis transforms are affected.
        :type axis_lock: typing.Optional[typing.Any]
    """

    ...

def quaternions_flip(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Flip quaternion values to achieve desired rotations, while maintaining the same orientations

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def relax(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    factor: typing.Optional[typing.Any] = 0.5,
    prev_frame: typing.Optional[typing.Any] = 0,
    next_frame: typing.Optional[typing.Any] = 0,
    channels: typing.Optional[typing.Any] = "ALL",
    axis_lock: typing.Optional[typing.Any] = "FREE",
):
    """Make the current pose more similar to its breakdown pose

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param factor: Factor, Weighting factor for which keyframe is favored more
        :type factor: typing.Optional[typing.Any]
        :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame
        :type prev_frame: typing.Optional[typing.Any]
        :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame
        :type next_frame: typing.Optional[typing.Any]
        :param channels: Channels, Set of properties that are affected

    ALL
    All Properties -- All properties, including transforms, bendy bone shape, and custom properties.

    LOC
    Location -- Location only.

    ROT
    Rotation -- Rotation only.

    SIZE
    Scale -- Scale only.

    BBONE
    Bendy Bone -- Bendy Bone shape properties.

    CUSTOM
    Custom Properties -- Custom properties.
        :type channels: typing.Optional[typing.Any]
        :param axis_lock: Axis Lock, Transform axis to restrict effects to

    FREE
    Free -- All axes are affected.

    X
    X -- Only X-axis transforms are affected.

    Y
    Y -- Only Y-axis transforms are affected.

    Z
    Z -- Only Z-axis transforms are affected.
        :type axis_lock: typing.Optional[typing.Any]
    """

    ...

def reveal(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    select: typing.Optional[typing.Union[bool, typing.Any]] = True,
):
    """Reveal all bones hidden in Pose Mode

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param select: Select
    :type select: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def rot_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Reset rotations of selected bones to their default values

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def rotation_mode_set(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    type: typing.Optional[typing.Union[str, int]] = "QUATERNION",
):
    """Set the rotation representation used by selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Rotation Mode
    :type type: typing.Optional[typing.Union[str, int]]
    """

    ...

def scale_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Reset scaling of selected bones to their default values

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def select_all(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    action: typing.Optional[typing.Any] = "TOGGLE",
):
    """Toggle selection status of all bones

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param action: Action, Selection action to execute

    TOGGLE
    Toggle -- Toggle selection for all elements.

    SELECT
    Select -- Select all elements.

    DESELECT
    Deselect -- Deselect all elements.

    INVERT
    Invert -- Invert selection of all elements.
        :type action: typing.Optional[typing.Any]
    """

    ...

def select_constraint_target(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Select bones used as targets for the currently selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def select_grouped(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    extend: typing.Optional[typing.Union[bool, typing.Any]] = False,
    type: typing.Optional[typing.Any] = "COLLECTION",
):
    """Select all visible bones grouped by similar properties

        :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
        :type execution_context: typing.Optional[typing.Union[str, int]]
        :type undo: typing.Optional[bool]
        :param extend: Extend, Extend selection instead of deselecting everything first
        :type extend: typing.Optional[typing.Union[bool, typing.Any]]
        :param type: Type

    COLLECTION
    Collection -- Same collections as the active bone.

    COLOR
    Color -- Same color as the active bone.

    KEYINGSET
    Keying Set -- All bones affected by active Keying Set.
        :type type: typing.Optional[typing.Any]
    """

    ...

def select_hierarchy(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    direction: typing.Optional[typing.Any] = "PARENT",
    extend: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Select immediate parent/children of selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param direction: Direction
    :type direction: typing.Optional[typing.Any]
    :param extend: Extend, Extend the selection
    :type extend: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def select_linked(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Select all bones linked by parent/child connections to the current selection

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def select_linked_pick(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    extend: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Select bones linked by parent/child connections under the mouse cursor

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param extend: Extend, Extend selection instead of deselecting everything first
    :type extend: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def select_mirror(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    only_active: typing.Optional[typing.Union[bool, typing.Any]] = False,
    extend: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Mirror the bone selection

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param only_active: Active Only, Only operate on the active bone
    :type only_active: typing.Optional[typing.Union[bool, typing.Any]]
    :param extend: Extend, Extend the selection
    :type extend: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def select_parent(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Select bones that are parents of the currently selected bones

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def transforms_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Reset location, rotation, and scaling of selected bones to their default values

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def user_transforms_clear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    only_selected: typing.Optional[typing.Union[bool, typing.Any]] = True,
):
    """Reset pose bone transforms to keyframed state

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param only_selected: Only Selected, Only visible/selected bones
    :type only_selected: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def visual_transform_apply(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Apply final constrained position of pose bones to their transform

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def bbone_resize(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
    orient_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Scale selected bendy bones display size

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Display Size
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def bend(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Bend selected items between the 3D cursor and the mouse

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def create_orientation(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    name: typing.Union[str, typing.Any] = "",
    use_view: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use: typing.Optional[typing.Union[bool, typing.Any]] = False,
    overwrite: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Create transformation orientation from selection

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param name: Name, Name of the new custom orientation
    :type name: typing.Union[str, typing.Any]
    :param use_view: Use View, Use the current view instead of the active object to create the new orientation
    :type use_view: typing.Optional[typing.Union[bool, typing.Any]]
    :param use: Use After Creation, Select orientation after its creation
    :type use: typing.Optional[typing.Union[bool, typing.Any]]
    :param overwrite: Overwrite Previous, Overwrite previously created orientation with same name
    :type overwrite: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def delete_orientation(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Delete transformation orientation

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def edge_bevelweight(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Change the bevel weight of edges

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def edge_crease(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Change the crease of edges

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def edge_slide(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    single_side: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_even: typing.Optional[typing.Union[bool, typing.Any]] = False,
    flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_clamp: typing.Optional[typing.Union[bool, typing.Any]] = True,
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_elements: typing.Optional[typing.Any] = {'"INCREMENT"'},
    use_snap_project: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_target: typing.Optional[typing.Union[str, int]] = "CLOSEST",
    use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    correct_uv: typing.Optional[typing.Union[bool, typing.Any]] = True,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Slide an edge loop along a mesh

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param single_side: Single Side
    :type single_side: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop
    :type use_even: typing.Optional[typing.Union[bool, typing.Any]]
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_clamp: Clamp, Clamp within the edge extents
    :type use_clamp: typing.Optional[typing.Union[bool, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap Base, Point on source that will snap to target
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Target: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Target: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Target: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Target: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming
    :type correct_uv: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def from_gizmo(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Transform selected items by mode type

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def mirror(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    orient_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Mirror selected items around one or more axes

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def push_pull(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Push/Pull selected items

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Distance
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def resize(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
    mouse_dir_constraint: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    orient_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_elements: typing.Optional[typing.Any] = {'"INCREMENT"'},
    use_snap_project: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_target: typing.Optional[typing.Union[str, int]] = "CLOSEST",
    use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    texture_space: typing.Optional[typing.Union[bool, typing.Any]] = False,
    remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_duplicated_keyframes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Scale (resize) selected items

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Scale
    :type value: typing.Optional[typing.Any]
    :param mouse_dir_constraint: Mouse Directional Constraint
    :type mouse_dir_constraint: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap Base, Point on source that will snap to target
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Target: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Target: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Target: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Target: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param texture_space: Edit Texture Space, Edit object data texture space
    :type texture_space: typing.Optional[typing.Union[bool, typing.Any]]
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
    :type remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_duplicated_keyframes: Duplicated Keyframes, Transform duplicated keyframes
    :type use_duplicated_keyframes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def rotate(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    orient_axis: typing.Optional[typing.Union[str, int]] = "Z",
    orient_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_elements: typing.Optional[typing.Any] = {'"INCREMENT"'},
    use_snap_project: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_target: typing.Optional[typing.Union[str, int]] = "CLOSEST",
    use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Rotate selected items

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap Base, Point on source that will snap to target
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Target: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Target: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Target: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Target: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def rotate_normal(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    orient_axis: typing.Optional[typing.Union[str, int]] = "Z",
    orient_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Rotate split normal of selected items

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def select_orientation(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    orientation: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
):
    """Select transformation orientation

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param orientation: Orientation, Transformation orientation
    :type orientation: typing.Optional[typing.Union[str, int, typing.Any]]
    """

    ...

def seq_slide(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = (0.0, 0.0),
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    view2d_edge_pan: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Slide a sequence strip in time

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param view2d_edge_pan: Edge Pan, Enable edge panning in 2D view
    :type view2d_edge_pan: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def shear(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    orient_axis: typing.Optional[typing.Union[str, int]] = "Z",
    orient_axis_ortho: typing.Optional[typing.Union[str, int]] = "X",
    orient_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Shear selected items along the given axis

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_axis_ortho: Axis Ortho
    :type orient_axis_ortho: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def shrink_fatten(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    use_even_offset: typing.Optional[typing.Union[bool, typing.Any]] = False,
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Shrink/fatten selected vertices along normals

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Offset
    :type value: typing.Optional[typing.Any]
    :param use_even_offset: Offset Even, Scale the offset to give more even thickness
    :type use_even_offset: typing.Optional[typing.Union[bool, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def skin_resize(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = (1.0, 1.0, 1.0),
    orient_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_elements: typing.Optional[typing.Any] = {'"INCREMENT"'},
    use_snap_project: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_target: typing.Optional[typing.Union[str, int]] = "CLOSEST",
    use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Scale selected vertices' skin radii

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Scale
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int, typing.Any]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap Base, Point on source that will snap to target
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Target: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Target: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Target: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Target: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def tilt(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Tilt selected control vertices of 3D curve

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def tosphere(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Move selected items outward in a spherical shape around geometric center

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def trackball(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = (0.0, 0.0),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Trackball style rotation of selected items

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Angle
    :type value: typing.Optional[typing.Any]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def transform(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    mode: typing.Optional[typing.Union[str, int]] = "TRANSLATION",
    value: typing.Optional[typing.Any] = (0.0, 0.0, 0.0, 0.0),
    orient_axis: typing.Optional[typing.Union[str, int]] = "Z",
    orient_type: typing.Optional[typing.Union[str, int]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_elements: typing.Optional[typing.Any] = {'"INCREMENT"'},
    use_snap_project: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_target: typing.Optional[typing.Union[str, int]] = "CLOSEST",
    use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    snap_align: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_normal: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    texture_space: typing.Optional[typing.Union[bool, typing.Any]] = False,
    remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_duplicated_keyframes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_automerge_and_split: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Transform selected items by mode type

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param mode: Mode
    :type mode: typing.Optional[typing.Union[str, int]]
    :param value: Values
    :type value: typing.Optional[typing.Any]
    :param orient_axis: Axis
    :type orient_axis: typing.Optional[typing.Union[str, int]]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap Base, Point on source that will snap to target
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Target: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Target: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Target: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Target: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param snap_align: Align with Point Normal
    :type snap_align: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_normal: Normal
    :type snap_normal: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param texture_space: Edit Texture Space, Edit object data texture space
    :type texture_space: typing.Optional[typing.Union[bool, typing.Any]]
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
    :type remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_duplicated_keyframes: Duplicated Keyframes, Transform duplicated keyframes
    :type use_duplicated_keyframes: typing.Optional[typing.Union[bool, typing.Any]]
    :param center_override: Center Override, Force using this center value (when set)
    :type center_override: typing.Optional[typing.Any]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_automerge_and_split: Auto Merge & Split, Forces the use of Auto Merge and Split
    :type use_automerge_and_split: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def translate(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    orient_type: typing.Optional[typing.Union[str, int]] = "GLOBAL",
    orient_matrix: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0),
    ),
    orient_matrix_type: typing.Optional[typing.Union[str, int]] = "GLOBAL",
    constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]] = (
        False,
        False,
        False,
    ),
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]] = False,
    proportional_edit_falloff: typing.Optional[typing.Union[str, int]] = "SMOOTH",
    proportional_size: typing.Optional[typing.Any] = 1.0,
    use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_elements: typing.Optional[typing.Any] = {'"INCREMENT"'},
    use_snap_project: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_target: typing.Optional[typing.Union[str, int]] = "CLOSEST",
    use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    snap_align: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_normal: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    cursor_transform: typing.Optional[typing.Union[bool, typing.Any]] = False,
    texture_space: typing.Optional[typing.Union[bool, typing.Any]] = False,
    remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_duplicated_keyframes: typing.Optional[typing.Union[bool, typing.Any]] = False,
    view2d_edge_pan: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_automerge_and_split: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Move selected items

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Move
    :type value: typing.Optional[typing.Any]
    :param orient_type: Orientation, Transformation orientation
    :type orient_type: typing.Optional[typing.Union[str, int]]
    :param orient_matrix: Matrix
    :type orient_matrix: typing.Optional[typing.Any]
    :param orient_matrix_type: Matrix Orientation
    :type orient_matrix_type: typing.Optional[typing.Union[str, int]]
    :param constraint_axis: Constraint Axis
    :type constraint_axis: typing.Optional[typing.Union[typing.List[bool], typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_edit: Proportional Editing
    :type use_proportional_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode
    :type proportional_edit_falloff: typing.Optional[typing.Union[str, int]]
    :param proportional_size: Proportional Size
    :type proportional_size: typing.Optional[typing.Any]
    :param use_proportional_connected: Connected
    :type use_proportional_connected: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_proportional_projected: Projected (2D)
    :type use_proportional_projected: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap Base, Point on source that will snap to target
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Target: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Target: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Target: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Target: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param snap_align: Align with Point Normal
    :type snap_align: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_normal: Normal
    :type snap_normal: typing.Optional[typing.Any]
    :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
    :type gpencil_strokes: typing.Optional[typing.Union[bool, typing.Any]]
    :param cursor_transform: Transform Cursor
    :type cursor_transform: typing.Optional[typing.Union[bool, typing.Any]]
    :param texture_space: Edit Texture Space, Edit object data texture space
    :type texture_space: typing.Optional[typing.Union[bool, typing.Any]]
    :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
    :type remove_on_cancel: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_duplicated_keyframes: Duplicated Keyframes, Transform duplicated keyframes
    :type use_duplicated_keyframes: typing.Optional[typing.Union[bool, typing.Any]]
    :param view2d_edge_pan: Edge Pan, Enable edge panning in 2D view
    :type view2d_edge_pan: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_automerge_and_split: Auto Merge & Split, Forces the use of Auto Merge and Split
    :type use_automerge_and_split: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def vert_crease(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Change the crease of vertices

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def vert_slide(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    value: typing.Optional[typing.Any] = 0.0,
    use_even: typing.Optional[typing.Union[bool, typing.Any]] = False,
    flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_clamp: typing.Optional[typing.Union[bool, typing.Any]] = True,
    mirror: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_elements: typing.Optional[typing.Any] = {'"INCREMENT"'},
    use_snap_project: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_target: typing.Optional[typing.Union[str, int]] = "CLOSEST",
    use_snap_self: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]] = True,
    use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]] = False,
    snap_point: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
    correct_uv: typing.Optional[typing.Union[bool, typing.Any]] = True,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
    use_accurate: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Slide a vertex along a mesh

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param value: Factor
    :type value: typing.Optional[typing.Any]
    :param use_even: Even, Make the edge loop match the shape of the adjacent edge loop
    :type use_even: typing.Optional[typing.Union[bool, typing.Any]]
    :param flipped: Flipped, When Even mode is active, flips between the two adjacent edge loops
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_clamp: Clamp, Clamp within the edge extents
    :type use_clamp: typing.Optional[typing.Union[bool, typing.Any]]
    :param mirror: Mirror Editing
    :type mirror: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap: Use Snapping Options
    :type snap: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_elements: Snap to Elements
    :type snap_elements: typing.Optional[typing.Any]
    :param use_snap_project: Project Individual Elements
    :type use_snap_project: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_target: Snap Base, Point on source that will snap to target
    :type snap_target: typing.Optional[typing.Union[str, int]]
    :param use_snap_self: Target: Include Active
    :type use_snap_self: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_edit: Target: Include Edit
    :type use_snap_edit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_nonedit: Target: Include Non-Edited
    :type use_snap_nonedit: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_snap_selectable: Target: Exclude Non-Selectable
    :type use_snap_selectable: typing.Optional[typing.Union[bool, typing.Any]]
    :param snap_point: Point
    :type snap_point: typing.Optional[typing.Any]
    :param correct_uv: Correct UVs, Correct UV coordinates when transforming
    :type correct_uv: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    :param use_accurate: Accurate, Use accurate transformation
    :type use_accurate: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def vertex_random(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    offset: typing.Optional[typing.Any] = 0.0,
    uniform: typing.Optional[typing.Any] = 0.0,
    normal: typing.Optional[typing.Any] = 0.0,
    seed: typing.Optional[typing.Any] = 0,
    wait_for_input: typing.Optional[typing.Union[bool, typing.Any]] = True,
):
    """Randomize vertices

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param offset: Amount, Distance to offset
    :type offset: typing.Optional[typing.Any]
    :param uniform: Uniform, Increase for uniform offset distance
    :type uniform: typing.Optional[typing.Any]
    :param normal: Normal, Align offset direction to normals
    :type normal: typing.Optional[typing.Any]
    :param seed: Random Seed, Seed for the random number generator
    :type seed: typing.Optional[typing.Any]
    :param wait_for_input: Wait for Input
    :type wait_for_input: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def vertex_warp(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    warp_angle: typing.Optional[typing.Any] = 6.28319,
    offset_angle: typing.Optional[typing.Any] = 0.0,
    min: typing.Optional[typing.Any] = -1.0,
    max: typing.Optional[typing.Any] = 1.0,
    viewmat: typing.Optional[typing.Any] = (
        (0.0, 0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0, 0.0),
        (0.0, 0.0, 0.0, 0.0),
    ),
    center: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
):
    """Warp vertices around the cursor

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param warp_angle: Warp Angle, Amount to warp about the cursor
    :type warp_angle: typing.Optional[typing.Any]
    :param offset_angle: Offset Angle, Angle to use as the basis for warping
    :type offset_angle: typing.Optional[typing.Any]
    :param min: Min
    :type min: typing.Optional[typing.Any]
    :param max: Max
    :type max: typing.Optional[typing.Any]
    :param viewmat: Matrix
    :type viewmat: typing.Optional[typing.Any]
    :param center: Center
    :type center: typing.Optional[typing.Any]
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

class _TokenizeDataPath:
    """ """

    data_path: typing.Any
    """ """

def decompose_data_path(data_path):
    """ """

    ...

def property_definition_from_data_path(base, data_path):
    """ """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

def build_property_typemap(skip_classes, skip_typemap):
    """ """

    ...

def print_ln(data):
    """ """

    ...

def rna2xml(
    fw,
    root_node,
    root_rna,
    root_rna_skip,
    root_ident,
    ident_val,
    skip_classes,
    skip_typemap,
    pretty_format,
    method,
):
    """ """

    ...

def xml2rna(root_xml, root_rna):
    """ """

    ...

def xml_file_run(context, filepath, rna_map):
    """ """

    ...

def xml_file_write(context, filepath, rna_map, skip_typemap):
    """ """

    ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def apply_pose_asset(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    blend_factor: typing.Optional[typing.Any] = 1.0,
    flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Apply the given Pose Action to the rig

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param blend_factor: Blend Factor, Amount that the pose is applied on top of the existing poses. A negative value will subtract the pose instead of adding it
    :type blend_factor: typing.Optional[typing.Any]
    :param flipped: Apply Flipped, When enabled, applies the pose flipped over the X-axis
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def blend_pose_asset(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    blend_factor: typing.Optional[typing.Any] = 0.0,
    flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
    release_confirm: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Blend the given Pose Action to the rig

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param blend_factor: Blend Factor, Amount that the pose is applied on top of the existing poses. A negative value will subtract the pose instead of adding it
    :type blend_factor: typing.Optional[typing.Any]
    :param flipped: Apply Flipped, When enabled, applies the pose flipped over the X-axis
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    :param release_confirm: Confirm on Release, Always confirm operation when releasing button
    :type release_confirm: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def convert_old_object_poselib(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Create a pose asset for each pose marker in this legacy pose library data-block

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def convert_old_poselib(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Create a pose asset for each pose marker in the current action

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def copy_as_asset(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Create a new pose asset on the clipboard, to be pasted into an Asset Browser

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def create_pose_asset(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    pose_name: typing.Union[str, typing.Any] = "",
    activate_new_action: typing.Optional[typing.Union[bool, typing.Any]] = True,
):
    """Create a new Action that contains the pose of the selected bones, and mark it as Asset. The asset will be stored in the current blend file

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param pose_name: Pose Name
    :type pose_name: typing.Union[str, typing.Any]
    :param activate_new_action: Activate New Action
    :type activate_new_action: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def paste_asset(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Paste the Asset that was previously copied using Copy As Asset

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...

def pose_asset_select_bones(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
    select: typing.Optional[typing.Union[bool, typing.Any]] = True,
    flipped: typing.Optional[typing.Union[bool, typing.Any]] = False,
):
    """Select those bones that are used in this pose

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param select: Select
    :type select: typing.Optional[typing.Union[bool, typing.Any]]
    :param flipped: Flipped
    :type flipped: typing.Optional[typing.Union[bool, typing.Any]]
    """

    ...

def restore_previous_action(
    override_context: typing.Optional[typing.Union[dict, bpy.types.Context]] = None,
    execution_context: typing.Optional[typing.Union[str, int]] = None,
    undo: typing.Optional[bool] = None,
):
    """Switch back to the previous Action, after creating a pose asset

    :type override_context: typing.Optional[typing.Union[dict, bpy.types.Context]]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    """

    ...



import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")

class CLIP_OT_bundles_to_mesh(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_constraint_to_fcurve(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_delete_proxy(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def invoke(self, context, event):
        """

        :param context:
        :param event:
        """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_filter_tracks(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_set_active_clip(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_set_viewport_background(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_setup_tracking_scene(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def createCollection(self, context, collection_name):
        """

        :param context:
        :param collection_name:
        """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_track_settings_as_default(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_track_settings_to_track(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

class CLIP_OT_track_to_empty(bpy_types.Operator):
    """ """

    bl_idname: typing.Any
    """ """

    bl_label: typing.Any
    """ """

    bl_options: typing.Any
    """ """

    bl_rna: typing.Any
    """ """

    id_data: typing.Any
    """ """

    def as_keywords(self, ignore):
        """

        :param ignore:
        """
        ...

    def as_pointer(self):
        """ """
        ...

    def bl_rna_get_subclass(self):
        """ """
        ...

    def bl_rna_get_subclass_py(self):
        """ """
        ...

    def driver_add(self):
        """ """
        ...

    def driver_remove(self):
        """ """
        ...

    def execute(self, context):
        """

        :param context:
        """
        ...

    def get(self):
        """ """
        ...

    def id_properties_clear(self):
        """ """
        ...

    def id_properties_ensure(self):
        """ """
        ...

    def id_properties_ui(self):
        """ """
        ...

    def is_property_hidden(self):
        """ """
        ...

    def is_property_overridable_library(self):
        """ """
        ...

    def is_property_readonly(self):
        """ """
        ...

    def is_property_set(self):
        """ """
        ...

    def items(self):
        """ """
        ...

    def keyframe_delete(self):
        """ """
        ...

    def keyframe_insert(self):
        """ """
        ...

    def keys(self):
        """ """
        ...

    def path_from_id(self):
        """ """
        ...

    def path_resolve(self):
        """ """
        ...

    def poll(self, context):
        """

        :param context:
        """
        ...

    def poll_message_set(self):
        """ """
        ...

    def pop(self):
        """ """
        ...

    def property_overridable_library_set(self):
        """ """
        ...

    def property_unset(self):
        """ """
        ...

    def type_recast(self):
        """ """
        ...

    def values(self):
        """ """
        ...

def CLIP_camera_for_clip(context, clip):
    """ """

    ...

def CLIP_default_settings_from_track(clip, track, framenr):
    """ """

    ...

def CLIP_set_viewport_background(context, clip, clip_user):
    """ """

    ...

def CLIP_spaces_walk(context, all_screens, tarea, tspace, callback, args):
    """ """

    ...

def CLIP_track_view_selected(sc, track):
    """ """

    ...



import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")

def bake_action(
    obj: bpy.types.Object,
    action: typing.Optional[bpy.types.Action],
    frames,
    bake_options,
) -> bpy.types.Action:
    """

        :param obj: Object to bake.
        :type obj: bpy.types.Object
        :param action: An action to bake the data into, or None for a new action
    to be created.
        :type action: typing.Optional[bpy.types.Action]
        :param frames: Frames to bake.
        :return: an action or None
        :rtype: bpy.types.Action
    """

    ...

def bake_action_iter(
    obj: bpy.types.Object, action: typing.Optional[bpy.types.Action], bake_options
) -> bpy.types.Action:
    """An coroutine that bakes action for a single object.

        :param obj: Object to bake.
        :type obj: bpy.types.Object
        :param action: An action to bake the data into, or None for a new action
    to be created.
        :type action: typing.Optional[bpy.types.Action]
        :param bake_options: Boolean options of what to include into the action bake.
        :return: an action or None
        :rtype: bpy.types.Action
    """

    ...

def bake_action_objects(
    object_action_pairs, frames, bake_options
) -> typing.Iterable[bpy.types.Action]:
    """A version of `bake_action_objects_iter` that takes frames and returns the output.

    :param frames: Frames to bake.
    :return: A sequence of Action or None types (aligned with object_action_pairs)
    :rtype: typing.Iterable[bpy.types.Action]
    """

    ...

def bake_action_objects_iter(object_action_pairs, bake_options):
    """An coroutine that bakes actions for multiple objects.

        :param object_action_pairs: Sequence of object action tuples,
    action is the destination for the baked data. When None a new action will be created.
    """

    ...



import typing

GenericType = typing.TypeVar("GenericType")

class AppOverrideState:
    """ """

    addon_paths: typing.Any
    """ """

    addons: typing.Any
    """ """

    class_ignore: typing.Any
    """ """

    ui_ignore_classes: typing.Any
    """ """

    ui_ignore_label: typing.Any
    """ """

    ui_ignore_menu: typing.Any
    """ """

    ui_ignore_operator: typing.Any
    """ """

    ui_ignore_property: typing.Any
    """ """

    def setup(self):
        """ """
        ...

    def teardown(self):
        """ """
        ...
